.. kitchen-sink

Kitchen Sink Example
===============================================================================

Here is an example showcasing most of the wx
based widgets:

.. literalinclude:: example.enaml
    :language: python

And the python script to execute it:

.. literalinclude:: example.py


Results in the following widget

.. figure:: images/example.png
    :align: center
    :figwidth: 70%
